@@ -34,7 +34,12 @@
 #include "factory.h"
 
 thread_local Process *localProcess;
-static int NumProcessActive = 0;
+
+void
+set_local_process(Process *p)
+{
+  localProcess = p;
+}
 
 int
 cdo_filetype(void)
@@ -48,12 +53,6 @@ cdo_filetype(void)
   return CdoDefault::FileType;
 }
 
-Process &
-process_self(void)
-{
-  return *localProcess;
-}
-
 void
 process_def_var_num(int nvars)
 {
@@ -162,12 +161,6 @@ operator_input_arg(const char *enter)
     }
 }
 
-int
-cdo_operator_add(const char *name, int f1, int f2, const char *enter)
-{
-  return localProcess->operator_add(name, f1, f2, enter);
-}
-
 int
 cdo_operator_id(void)
 {
@@ -177,37 +170,37 @@ cdo_operator_id(void)
 int
 cdo_operator_f1(int operID)
 {
-  return localProcess->oper[operID].f1;
+  return localProcess->m_module.operators[operID].f1;
 }
 
 int
 cdo_operator_f2(int operID)
 {
-  return localProcess->oper[operID].f2;
+  return localProcess->m_module.operators[operID].f2;
 }
 
 const char *
 cdo_operator_name(int operID)
 {
-  return localProcess->oper[operID].name.c_str();
+  return localProcess->m_module.operators[operID].name.c_str();
 }
 
 std::string
 cdo_module_name()
 {
-  return get_module_name_to(cdo_operator_name(cdo_operator_id()));
+  return localProcess->m_module.name;
 }
 
 const char *
 cdo_operator_enter(int operID)
 {
-  return localProcess->oper[operID].enter;
+  return localProcess->m_module.operators[operID].enter;
 }
 
 int
 cdo_stream_number()
 {
-  return operator_stream_number(localProcess->operatorName);
+  return localProcess->m_module.get_number();
 }
 
 int
@@ -350,23 +343,6 @@ cdo_get_obase()
   return localProcess->get_obase();
 }
 
-void
-cdo_initialize(void *p_process)
-{
-#if defined(_OPENMP)
-  omp_set_num_threads(Threading::ompNumThreads);  // Has to be called for every module (pthread)!
-#endif
-  localProcess = (Process *) p_process;
-#ifdef HAVE_LIBPTHREAD
-  localProcess->threadID = pthread_self();
-#endif
-  Debug(PROCESS_INT, "Initializing process: %s (id: %d)", localProcess->operatorName, localProcess->get_id());
-
-#ifdef HAVE_LIBPTHREAD
-  Debug(PROCESS_INT, "process %d thread %ld", localProcess->m_ID, pthread_self());
-#endif
-}
-
 const char *
 process_inq_prompt(void)
 {
@@ -375,24 +351,6 @@ process_inq_prompt(void)
 
 extern "C" size_t getPeakRSS();
 
-void
-cdo_finish(void)
-{
-  assert(((void) "Internal error: module not initialized!", (localProcess != nullptr)));
-
-  Debug(PROCESS_INT, "Finishing process: %d", localProcess->m_ID);
-
-#ifdef HAVE_LIBPTHREAD
-  Debug(PROCESS_INT, "process %d thread %ld", localProcess->m_ID, pthread_self());
-#endif
-
-  if (!Options::silentMode && (cdo::stdoutIsTerminal || Options::cdoVerbose)) localProcess->print_processed_values();
-
-  // localProcess->close_streams();
-  localProcess->set_inactive();
-  NumProcessActive--;
-}
-
 /* TODO move cdoClose internals into Pstream::close/ CdoStream::close */
 void
 cdo_stream_close(CdoStreamID pstreamPtr)
@@ -425,34 +383,34 @@ cdo_stream_inq_vlist(CdoStreamID p_pstreamPtr)
 
 // - - - - - - -
 void
-cdo_write_record_f(CdoStreamID p_pstreamPtr, float *data, size_t nmiss)
+cdo_write_record_f(CdoStreamID p_pstreamPtr, float *data, size_t numMissVals)
 {
-  p_pstreamPtr->write_record(data, nmiss);
+  p_pstreamPtr->write_record(data, numMissVals);
 }
 
 void
-cdo_write_record(CdoStreamID p_pstreamPtr, double *data, size_t nmiss)
+cdo_write_record(CdoStreamID p_pstreamPtr, double *data, size_t numMissVals)
 {
-  p_pstreamPtr->write_record(data, nmiss);
+  p_pstreamPtr->write_record(data, numMissVals);
 }
 
 void
 cdo_write_record(CdoStreamID p_pstreamPtr, Field &field)
 {
   if (field.memType == MemType::Float)
-    cdo_write_record_f(p_pstreamPtr, field.vec_f.data(), field.nmiss);
+    cdo_write_record_f(p_pstreamPtr, field.vec_f.data(), field.numMissVals);
   else
-    cdo_write_record(p_pstreamPtr, field.vec_d.data(), field.nmiss);
+    cdo_write_record(p_pstreamPtr, field.vec_d.data(), field.numMissVals);
 }
 
 void
-cdo_write_record(CdoStreamID p_pstreamPtr, Field3D &field, int levelID, size_t nmiss)
+cdo_write_record(CdoStreamID p_pstreamPtr, Field3D &field, int levelID, size_t numMissVals)
 {
   const auto offset = levelID * field.gridsize * field.nwpv;
   if (field.memType == MemType::Float)
-    cdo_write_record_f(p_pstreamPtr, field.vec_f.data() + offset, nmiss);
+    cdo_write_record_f(p_pstreamPtr, field.vec_f.data() + offset, numMissVals);
   else
-    cdo_write_record(p_pstreamPtr, field.vec_d.data() + offset, nmiss);
+    cdo_write_record(p_pstreamPtr, field.vec_d.data() + offset, numMissVals);
 }
 // - - - - - - -
 void
@@ -489,36 +447,36 @@ cdo_inq_byteorder(CdoStreamID p_pstreamPtr)
 
 // - - - - - - -
 void
-cdo_read_record_f(CdoStreamID p_pstreamPtr, float *data, size_t *nmiss)
+cdo_read_record_f(CdoStreamID p_pstreamPtr, float *data, size_t *numMissVals)
 {
   if (data == nullptr) cdo_abort("Data pointer not allocated (cdo_read_record)!");
-  p_pstreamPtr->read_record(data, nmiss);
+  p_pstreamPtr->read_record(data, numMissVals);
 }
 
 void
-cdo_read_record(CdoStreamID p_pstreamPtr, double *data, size_t *nmiss)
+cdo_read_record(CdoStreamID p_pstreamPtr, double *data, size_t *numMissVals)
 {
   if (data == nullptr) cdo_abort("Data pointer not allocated (cdo_read_record)!");
-  p_pstreamPtr->read_record(data, nmiss);
+  p_pstreamPtr->read_record(data, numMissVals);
 }
 
 void
 cdo_read_record(CdoStreamID streamID, Field &field)
 {
   if (field.memType == MemType::Float)
-    cdo_read_record_f(streamID, field.vec_f.data(), &field.nmiss);
+    cdo_read_record_f(streamID, field.vec_f.data(), &field.numMissVals);
   else
-    cdo_read_record(streamID, field.vec_d.data(), &field.nmiss);
+    cdo_read_record(streamID, field.vec_d.data(), &field.numMissVals);
 }
 
 void
-cdo_read_record(CdoStreamID streamID, Field3D &field, int levelID, size_t *nmiss)
+cdo_read_record(CdoStreamID streamID, Field3D &field, int levelID, size_t *numMissVals)
 {
   const auto offset = levelID * field.gridsize * field.nwpv;
   if (field.memType == MemType::Float)
-    cdo_read_record_f(streamID, field.vec_f.data() + offset, nmiss);
+    cdo_read_record_f(streamID, field.vec_f.data() + offset, numMissVals);
   else
-    cdo_read_record(streamID, field.vec_d.data() + offset, nmiss);
+    cdo_read_record(streamID, field.vec_d.data() + offset, numMissVals);
 }
 // - - - - - - -
 
